Range-v3: meta::id< T > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Types | List of all members
meta::id< T > Struct Template Reference
Meta » Trait Meta » Trait » | Invocation

## Description

### template<typename T>
struct meta::id< T >

A trait that always returns its argument `T`. Also, a Callable that always returns `T`.

## Public Types
template<typename... >
using | invoke = T
using | type = T